### APITestka
> Project Kanban \
> https://github.com/users/JE-Chen/projects/35 \
> Simple way to testing HTTP/S & Soap \
> Wrapper for Requests package, designed for those with experience using Requests. \
> Send HTTP/S and SOAP requests with a simple line of code or keyword. \
> Detailed information on Requests and Responses. \
> Solves problems such as:
>> * Detailed testing reports on Requests and Responses.
>> * Testing for SOAP protocol.
>> * Data comparison for each Request.
>> * API Testing in pure CLI mode.
---
### Features

>* HTTP Method test
>* Get response data body etc...
>* Action file and executor
>* result compare
>* xml to json and json to xml
>* Soap test
>* Generate HTML Report
>* CLI with action file

---

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/f243c4edfc1f4aa3ac87752e3e86b399)](https://www.codacy.com/gh/JE-Chen/APITestka/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/APITestka&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/Integrated-Testing-Environment/APITestka/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/Integrated-Testing-Environment/APITestka/tree/main)

[![APITestka GitHub Actions Dev](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_dev.yml)

[![AutoControl GitHub Actions Stable](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/apitestka/badge/?version=latest)](https://apitestka.readthedocs.io/en/latest/?badge=latest)

https://apitestka.readthedocs.io/en/latest/

---

## install
> pip install je_api_testka


## Requires
> python 3.7 or later